@@ -5,6 +5,10 @@ file_path = os.path.abspath(__file__)
 end = file_path.index('mns') + 17
 project_path = file_path[0:end]
 sys.path.append(project_path)
+import warnings
+
+# 忽略所有警告
+warnings.filterwarnings("ignore")
 import mns_scheduler.company_info.em_stock_info.sync_em_stock_info_sync as sync_em_stock_info_sync
 import mns_scheduler.self_choose.ths_self_choose_service as ths_self_choose_service
 import mns_scheduler.risk.major_violations.register_and_investigate_stock_sync_api \
@@ -477,7 +481,7 @@ blockingScheduler.add_job(self_choose_stock_task, 'cron', hour='08,17,21', minut
 blockingScheduler.add_job(sync_new_concept_index, 'cron', hour='09,22', minute='01,10,20,28,41,58')
 
 # 获取同花顺持仓
-blockingScheduler.add_job(sync_position, 'cron', hour='0,09', minute='10')
+blockingScheduler.add_job(sync_position, 'cron', hour='0,08,09', minute='14')
 
 # 更新同花顺概念信息
 blockingScheduler.add_job(concept_info_clean, 'cron', hour='9,12,20', minute='24')
